import { httpDelete, httpGet, httpPost, httpPut } from '../../utils/http'
import {
  PointsOrder,
  ResPageData,
  Todo,
  Agent,
  Designer,
  AgentTask,
  ReportInfo,
  FollowUp,
} from '@designer-hub/app/src/core/libs/models'
/**
 * 通过ID获取用户信息
 */
export const getUserInfoById = (id) =>
  httpGet<
    Partial<{
      mobile: string
      status: string
      nickname: string
      avatar: string
      name: string
      sex: string
      areaId: number
      areaName: string
      birthday: string
      mark: string
      tagIds: string
      levelId: number
      groupId: number
      id: number
      registerIp: string
      loginIp: string
      loginDate: string
      createTime: string
      point: number
      totalPoint: number
      tagNames: string
      levelName: string
      groupName: string
      experience: number
    }>
  >('/app-api/member/user/getByUserId', { id })
/**
 * 获取设计师信息
 */
// export const getDesignerInfo = (userId: number) =>
//   httpGet<Designer>('/app-api/member/designer/getDesignerInfo', { userId })
/**
 * 获取设计师基本信息
 */
export const getStylistBasicInfo = (userId: number) =>
  httpGet<Designer>('/app-api/member/stylist-basic-info/get', { userId })
/**
 * 设计师列表
 */
export const getDesigners = (query = {}) =>
  httpGet<ResPageData<Designer>>('/app-api/member/app-broker/pageStylist', query)
/**
 * 任务列表
 */
export const getTasks = (query = {}) =>
  httpGet<ResPageData<AgentTask>>('/app-api/member/task/page', query)
/**
 * 关系报备
 */
export const getReportInfoPage = (query = {}) =>
  httpGet<ResPageData<ReportInfo>>('/app-api/member/report-info/page', query)
/**
 * 删除关系报备
 */
export const deleteReportInfo = (id: number) =>
  httpDelete(`/app-api/member/report-info/delete`, { id })
/**
 * 创建设计师跟进
 */
export const createFollowUp = (data: Partial<FollowUp>) =>
  httpPost('/app-api/member/stylist-follow-up/create', data)
/**
 * 获取设计师跟进列表
 */
export const getFollowUpPage = (query = {}) =>
  httpGet<ResPageData<FollowUp & { followTypeName: string; brokerName: string }>>(
    '/app-api/member/stylist-follow-up/page',
    query,
  )
/**
 * 更新设计师跟进
 */
export const updateFollowUp = (data: Partial<FollowUp>) =>
  httpPut('/app-api/member/stylist-follow-up/update', data)
/**
 * /app-api/member/user-auth-info/focus 重点跟进或取消
 */
export const focusOrCancel = (data: { brokerId: number; userId: number }) =>
  httpPost('/app-api/member/user-auth-info/focus', data)
